==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/smarttextsadjustdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "smarttextsadjustdialog.h"

#include <qlabel.h>
#include <qgroupbox.h>
#include <qlayout.h>

#include <klocale.h>
#include <knuminput.h>


using namespace SubtitleComposer;

SmartTextsAdjustDialog::SmartTextsAdjustDialog( unsigned minLengthForLineBreak, QWidget* parent ):
	TargetableTextsActionDialog( i18n( "Smart Lines Adjust" ), parent )
{
	QGroupBox* settingsGroupBox = createGroupBox( i18n( "Settings" ) );

	QLabel* m_minLengthForLineBreakLabel = new QLabel( i18n( "Minimum length for line break" ), settingsGroupBox );
	m_minLengthForLineBreakLabel->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );

	m_minLengthForLineBreakSpinBox = new KIntSpinBox( settingsGroupBox );
	m_minLengthForLineBreakSpinBox->setMinValue( 0 );
	m_minLengthForLineBreakSpinBox->setMaxValue( 1000 );
	m_minLengthForLineBreakSpinBox->setValue( minLengthForLineBreak );

	QGridLayout* settingsLayout = createLayout( settingsGroupBox );
	settingsLayout->addWidget( m_minLengthForLineBreakLabel, 0, 0 );
	settingsLayout->addWidget( m_minLengthForLineBreakSpinBox, 0, 1 );

	createTextsTargetGroupBox();
	createLinesTargetGroupBox();
}

unsigned SmartTextsAdjustDialog::minLengthForLineBreak()
{
	return m_minLengthForLineBreakSpinBox->value();
}

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/main/dialogs/smarttextsadjustdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "smarttextsadjustdialog.h"

#include <qlabel.h>
#include <qbuttongroup.h>
#include <qlayout.h>

#include <klocale.h>
#include <knuminput.h>

using namespace SubtitleComposer;

SmartTextsAdjustDialog::SmartTextsAdjustDialog( unsigned minLengthForLineBreak, QWidget* parent ):
	ActionWithTargetDialog( i18n( "Smart Lines Adjust" ), parent )
{
	QButtonGroup* settingsButtonGroup = createButtonGroup( i18n( "Settings" ) );

	QLabel* minLengthForLineBreakLabel = new QLabel( i18n( "Minimum length for line break" ), settingsButtonGroup );
	minLengthForLineBreakLabel->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );

	m_minLengthForLineBreakSpinBox = new KIntSpinBox( settingsButtonGroup );
	m_minLengthForLineBreakSpinBox->setMinValue( 0 );
	m_minLengthForLineBreakSpinBox->setMaxValue( 1000 );
	m_minLengthForLineBreakSpinBox->setValue( minLengthForLineBreak );
	m_minLengthForLineBreakSpinBox->setSuffix( i18n( " characters" ) );

	createLinesTargetButtons();
	createTextsTargetButtons();


	QGridLayout* settingsLayout = createLayout( settingsButtonGroup );
	settingsLayout->addWidget( minLengthForLineBreakLabel, 0, 0 );
	settingsLayout->addWidget( m_minLengthForLineBreakSpinBox, 0, 1 );
}

unsigned SmartTextsAdjustDialog::minLengthForLineBreak() const
{
	return m_minLengthForLineBreakSpinBox->value();
}
